==> hs-attoparsec-enumerator-0.3.tbz: lib/ghc-7.0.4/cabal/attoparsec-enumerator-0.3/register.sh <==
#!/bin/sh
echo 'name: attoparsec-enumerator
version: 0.3
id: attoparsec-enumerator-0.3-034c77a22365cdb87c951eede980060d

license: MIT
copyright:
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/attoparsec-enumerator/
package-url:
description: This library allows an Attoparsec parser to receive input incrementally
             from an enumerator. This could be used for parsing large files, or
             implementing binary network protocols.
             .
             > (-# LANGUAGE OverloadedStrings #-)
             >
             > import Control.Applicative
             > import Data.Attoparsec
             > import Data.Attoparsec.Enumerator
             > import Data.Enumerator
             > import Data.Enumerator.Binary (enumHandle)
             > import Data.Enumerator.List
             > import System.IO
             >
             > parser = string "foo" <|> string "bar"
             >
             > main = do
             >     xy <- run_ (enumHandle 1 stdin $$ do
             >         x <- iterParser parser
             >         y <- iterParser parser
             >         return (x, y))
             >     print xy
category: Text, Parsing, Enumerator
author: John Millikin <jmillikin@gmail.com>
exposed: True
exposed-modules: Data.Attoparsec.Enumerator
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/attoparsec-enumerator-0.3
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/attoparsec-enumerator-0.3
              /usr/local/lib
hs-libraries: HSattoparsec-enumerator-0.3
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: attoparsec-0.10.1.0-d48602bcab8a927c27afa06cc0583921
         base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         bytestring-0.9.1.10-94a0a1c920aee21a485bdf21fd51b2be
         enumerator-0.4.18-c00de8fe8140ebfbb8bd3fe05ae490f1
         text-0.11.1.5-b4f492f688b9a01c2b4d3a9904e832bc
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/attoparsec-enumerator-0.3/html/attoparsec-enumerator.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/attoparsec-enumerator-0.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-attoparsec-enumerator-0.3.1_2.tbz: lib/ghc-7.4.2/cabal/attoparsec-enumerator-0.3.1/register.sh <==
#!/bin/sh
echo 'name: attoparsec-enumerator
version: 0.3.1
id: attoparsec-enumerator-0.3.1-bdc7b2ba4fbec2d544d29f75fb95bedf

license: MIT
copyright:
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/attoparsec-enumerator/
package-url:
synopsis: Pass input from an enumerator to an Attoparsec parser.
description: This library allows an Attoparsec parser to receive input incrementally
             from an enumerator. This could be used for parsing large files, or
             implementing binary network protocols.
             .
             > (-# LANGUAGE OverloadedStrings #-)
             >
             > import Control.Applicative
             > import Data.Attoparsec
             > import Data.Attoparsec.Enumerator
             > import Data.Enumerator
             > import Data.Enumerator.Binary (enumHandle)
             > import Data.Enumerator.List
             > import System.IO
             >
             > parser = string "foo" <|> string "bar"
             >
             > main = do
             >     xy <- run_ (enumHandle 1 stdin $$ do
             >         x <- iterParser parser
             >         y <- iterParser parser
             >         return (x, y))
             >     print xy
category: Text, Parsing, Enumerator
author: John Millikin <jmillikin@gmail.com>
exposed: True
exposed-modules: Data.Attoparsec.Enumerator
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/attoparsec-enumerator-0.3.1
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/attoparsec-enumerator-0.3.1
              /usr/local/lib
hs-libraries: HSattoparsec-enumerator-0.3.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: attoparsec-0.10.4.0-dbd6937f542b517f5587aeb94985f872
         base-4.5.1.0-12fddc14a7babb909dd3843e453b5660
         bytestring-0.9.2.1-e22c77999d0db34f3ca8de7082a3ffd5
         enumerator-0.4.19-54652fc37c21c9ff6bc4aced898d00e5
         text-0.11.2.3-366962ac4488fc093d5aed19e281b055
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/attoparsec-enumerator-0.3.1/html/attoparsec-enumerator.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/attoparsec-enumerator-0.3.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
